# CHANGELOG


## v0.1.1 (2026-01-31)

### Bug Fixes

- Resolve integration test failures against EHRBase 2.0 (#18)
  ([#18](https://github.com/platzhersh/oehrpy/pull/18),
  [`ca63003`](https://github.com/platzhersh/oehrpy/commit/ca6300326200e5a497f895c6a6f0ce67d4fecffc))


## v0.1.0 (2026-01-31)

### Bug Fixes

- Install build module inside semantic-release Docker container (#17)
  ([#17](https://github.com/platzhersh/oehrpy/pull/17),
  [`23ced62`](https://github.com/platzhersh/oehrpy/commit/23ced6206b6f18ad8e55576c3201b0afdb60685a))

- Update FLAT format paths based on EHRBase 2.26.0 web template (#11)
  ([#11](https://github.com/platzhersh/oehrpy/pull/11),
  [`1a4d0aa`](https://github.com/platzhersh/oehrpy/commit/1a4d0aaca0640711ceef771e00ba5e16560ee523))

### Documentation

- Add contribution guidelines (#14) ([#14](https://github.com/platzhersh/oehrpy/pull/14),
  [`8b12373`](https://github.com/platzhersh/oehrpy/commit/8b123738235b96e226e356ff9a0484a056f639c8))

- Add OPT Parser documentation to GitHub Pages (#9)
  ([#9](https://github.com/platzhersh/oehrpy/pull/9),
  [`7ed27de`](https://github.com/platzhersh/oehrpy/commit/7ed27de53baaddc53c50e23cc4d4613495f339bf))

### Features

- Add automated release workflow with python-semantic-release (#16)
  ([#16](https://github.com/platzhersh/oehrpy/pull/16),
  [`8201f6a`](https://github.com/platzhersh/oehrpy/commit/8201f6aadc9b7e008bcaf5d4a12c0880222852e1))

- Add complete OPT (Operational Template) support with builder generation (#8)
  ([#8](https://github.com/platzhersh/oehrpy/pull/8),
  [`f938e23`](https://github.com/platzhersh/oehrpy/commit/f938e23293db86c613b041e8301403367325b82c))

- Add GitHub Actions CI/CD workflow (#3) ([#3](https://github.com/platzhersh/oehrpy/pull/3),
  [`ad43fdd`](https://github.com/platzhersh/oehrpy/commit/ad43fdd104dea399efdc013f718ee94f9df01ad5))

- Add PyPI publishing support (#13) ([#13](https://github.com/platzhersh/oehrpy/pull/13),
  [`052e447`](https://github.com/platzhersh/oehrpy/commit/052e44759657f036114e7eab8a652b0cb0883aae))

- Implement features from PRD-0000 (#2) ([#2](https://github.com/platzhersh/oehrpy/pull/2),
  [`829ea0b`](https://github.com/platzhersh/oehrpy/commit/829ea0bde75e20d1b72c4c2409c0ed0cb3084cfa))

- Set up GitHub Pages with landing page and brand kit (#4)
  ([#4](https://github.com/platzhersh/oehrpy/pull/4),
  [`aa65777`](https://github.com/platzhersh/oehrpy/commit/aa657770be4a2da13898c83b3bc21abe475f3ac3))

### Testing

- Add integration test setup with ehrbase (#10)
  ([#10](https://github.com/platzhersh/oehrpy/pull/10),
  [`f1a2aa0`](https://github.com/platzhersh/oehrpy/commit/f1a2aa00669cf46b265a8209c9a012436de9a980))
